@@ -12,8 +12,8 @@
  *
  * This file is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
- * Software Foundation; either version 3 of the License, or (at your option) any
- * later version.
+ * Software Foundation; either version 2.1 of the License, or (at your option)
+ * any later version.
  *
  * This file is distributed in the hope that it will be useful, but WITHOUT
  * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -74,6 +74,13 @@
 #  define ENOATTR ENODATA
 #endif
 
+#ifndef RENAME_NOREPLACE
+#  define RENAME_NOREPLACE	(1 << 0)
+#endif
+#ifndef RENAME_EXCHANGE
+#  define RENAME_EXCHANGE	(1 << 1)
+#endif
+
 #define WIMFS_MQUEUE_NAME_LEN 32
 
 #define WIMLIB_UNMOUNT_FLAG_SEND_PROGRESS 0x80000000
