@@ -23,7 +23,7 @@ ZIP=false
 ZIPFILE=
 
 PREBUILT_LLVM_MINGW_ENABLED=false
-PREBUILT_LLVM_MINGW_URL=https://github.com/mstorsjo/llvm-mingw/releases/download/20230320/llvm-mingw-20230320-msvcrt-x86_64.zip
+PREBUILT_LLVM_MINGW_URL=https://github.com/mstorsjo/llvm-mingw/releases/download/20251216/llvm-mingw-20251216-msvcrt-x86_64.zip
 PREBUILT_LLVM_MINGW_ZIP=$(basename "$PREBUILT_LLVM_MINGW_URL")
 PREBUILT_LLVM_MINGW=${PREBUILT_LLVM_MINGW_ZIP%.zip}
 PREBUILT_LLVM_MINGW_BIN="/$PREBUILT_LLVM_MINGW/bin"
@@ -67,10 +67,6 @@ parse_options()
 		ARCH=x86_64
 		CC_PKG=mingw-w64-x86_64-gcc
 		;;
-	CLANG32)
-		ARCH=i686
-		CC_PKG=mingw-w64-clang-i686-clang
-		;;
 	CLANG64)
 		ARCH=x86_64
 		CC_PKG=mingw-w64-clang-x86_64-clang
@@ -88,7 +84,7 @@ parse_options()
 		;;
 	*)
 		echo 1>&2 "Unsupported MSYS2 environment: $MSYSTEM.  This script supports"
-		echo 1>&2 "MINGW32, MINGW64, CLANG32, CLANG64, and CLANGARM64."
+		echo 1>&2 "MINGW32, MINGW64, CLANG64, and CLANGARM64."
 		echo 1>&2 "See https://www.msys2.org/docs/environments/"
 		exit 1
 	esac
